@@ -9,22 +9,20 @@ library(admiraldev)
 ## ----message=FALSE------------------------------------------------------------
 library(admiral)
 library(dplyr, warn.conflicts = FALSE)
-library(admiral.test)
+library(pharmaversesdtm)
 library(lubridate)
 library(stringr)
 library(tibble)
 
-data("admiral_adsl")
-data("admiral_vs")
+vs <- pharmaversesdtm::vs
+adsl <- admiral::admiral_adsl
 
-adsl <- admiral_adsl
-vs <- convert_blanks_to_na(admiral_vs)
+vs <- convert_blanks_to_na(vs)
 
 ## ----echo=FALSE---------------------------------------------------------------
 vs <- filter(vs, USUBJID %in% c("01-701-1015", "01-701-1023", "01-703-1086", "01-703-1096", "01-707-1037", "01-716-1024"))
 
 ## ----eval=TRUE----------------------------------------------------------------
-
 adsl_vars <- exprs(TRTSDT, TRTEDT, TRT01A, TRT01P)
 
 advs <- derive_vars_merged(
@@ -34,7 +32,7 @@ advs <- derive_vars_merged(
   by_vars = exprs(STUDYID, USUBJID)
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, VSTESTCD, VSDTC, VISIT, TRTSDT, TRTEDT, TRT01A, TRT01P),
@@ -44,7 +42,7 @@ dataset_vignette(
 ## ----eval=TRUE----------------------------------------------------------------
 advs <- derive_vars_dt(advs, new_vars_prefix = "A", dtc = VSDTC)
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, VISIT, VSDTC, ADT),
@@ -72,7 +70,7 @@ advs <- derive_vars_dt(
   highest_imputation = "M"
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, VISIT, VSDTC, ADT, ADTF),
@@ -83,20 +81,20 @@ dataset_vignette(
 advs <- advs_old
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  # CDISC Pilot data does not contain times and the output of the derivation
-#  # ADTM is not presented.
-#  advs <- derive_vars_dtm(
-#    advs,
-#    new_vars_prefix = "A",
-#    dtc = VSDTC,
-#    highest_imputation = "M"
-#  )
+# # CDISC Pilot data does not contain times and the output of the derivation
+# # ADTM is not presented.
+# advs <- derive_vars_dtm(
+#   advs,
+#   new_vars_prefix = "A",
+#   dtc = VSDTC,
+#   highest_imputation = "M"
+# )
 
 ## ----eval=TRUE----------------------------------------------------------------
 advs <-
   derive_vars_dy(advs, reference_date = TRTSDT, source_vars = exprs(ADT))
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, VISIT, ADT, ADY, TRTSDT),
@@ -104,16 +102,16 @@ dataset_vignette(
 )
 
 ## ----eval=TRUE, include=FALSE-------------------------------------------------
-param_lookup <- tribble(
-  ~VSTESTCD, ~PARAMCD, ~PARAM, ~PARAMN, ~PARCAT1, ~PARCAT1N,
-  "HEIGHT", "HEIGHT", "Height (cm)", 1, "Subject Characteristic", 1,
-  "WEIGHT", "WEIGHT", "Weight (kg)", 2, "Subject Characteristic", 1,
-  "DIABP", "DIABP", "Diastolic Blood Pressure (mmHg)", 3, "Vital Sign", 2,
-  "MAP", "MAP", "Mean Arterial Pressure (mmHg)", 4, "Vital Sign", 2,
-  "BSA", "BSA", "Body Surface Area (m^2)", 5, "Vital Sign", 2,
-  "PULSE", "PULSE", "Pulse Rate (beats/min)", 6, "Vital Sign", 2,
-  "SYSBP", "SYSBP", "Systolic Blood Pressure (mmHg)", 7, "Vital Sign", 2,
-  "TEMP", "TEMP", "Temperature (C)", 8, "Vital Sign", 2
+param_lookup <- tibble::tribble(
+  ~VSTESTCD, ~PARAMCD,                            ~PARAM, ~PARAMN,                 ~PARCAT1, ~PARCAT1N,
+  "HEIGHT",  "HEIGHT",                     "Height (cm)",       1, "Subject Characteristic",         1,
+  "WEIGHT",  "WEIGHT",                     "Weight (kg)",       2, "Subject Characteristic",         1,
+  "DIABP",    "DIABP", "Diastolic Blood Pressure (mmHg)",       3,             "Vital Sign",         2,
+  "MAP",        "MAP",   "Mean Arterial Pressure (mmHg)",       4,             "Vital Sign",         2,
+  "BSA",        "BSA",         "Body Surface Area (m^2)",       5,             "Vital Sign",         2,
+  "PULSE",    "PULSE",          "Pulse Rate (beats/min)",       6,             "Vital Sign",         2,
+  "SYSBP",    "SYSBP",  "Systolic Blood Pressure (mmHg)",       7,             "Vital Sign",         2,
+  "TEMP",      "TEMP",                 "Temperature (C)",       8,             "Vital Sign",         2
 )
 attr(param_lookup$VSTESTCD, "label") <- "Vital Signs Test Short Name"
 
@@ -125,7 +123,7 @@ advs <- derive_vars_merged_lookup(
   by_vars = exprs(VSTESTCD)
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 advs_param <- distinct(advs, USUBJID, PARAMCD, VSTESTCD)
 
 dataset_vignette(advs_param, display_vars = exprs(USUBJID, VSTESTCD, PARAMCD))
@@ -133,14 +131,13 @@ dataset_vignette(advs_param, display_vars = exprs(USUBJID, VSTESTCD, PARAMCD))
 ## ----eval=TRUE----------------------------------------------------------------
 advs <- mutate(
   advs,
-  AVAL = VSSTRESN,
-  AVALC = VSSTRESC
+  AVAL = VSSTRESN
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
-  display_vars = exprs(VSTESTCD, PARAMCD, VSSTRESN, VSSTRESC, AVAL, AVALC),
+  display_vars = exprs(VSTESTCD, PARAMCD, VSSTRESN, VSSTRESC, AVAL),
   filter = USUBJID == "01-716-1024"
 )
 
@@ -153,10 +150,10 @@ advs <- derive_param_map(
   filter = VSSTAT != "NOT DONE" | is.na(VSSTAT)
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   arrange(advs, USUBJID, VISITNUM, VSTPTNUM, ADT, PARAMCD),
-  display_vars = exprs(VSTESTCD, PARAMCD, VISIT, VSTPT, AVAL, AVALC),
+  display_vars = exprs(VSTESTCD, PARAMCD, VISIT, VSTPT, AVAL),
   filter = USUBJID == "01-701-1015" & PARAMCD %in% c("MAP", "DIABP", "SYSBP")
 )
 
@@ -167,7 +164,8 @@ advs <- derive_param_bsa(
   method = "Mosteller",
   set_values_to = exprs(PARAMCD = "BSA"),
   get_unit_expr = VSSTRESU,
-  filter = VSSTAT != "NOT DONE" | is.na(VSSTAT)
+  filter = VSSTAT != "NOT DONE" | is.na(VSSTAT),
+  constant_by_vars = exprs(USUBJID)
 )
 
 advs <- derive_param_bmi(
@@ -175,59 +173,58 @@ advs <- derive_param_bmi(
   by_vars = exprs(STUDYID, USUBJID, !!!adsl_vars, VISIT, VISITNUM, ADT, ADY, VSTPT, VSTPTNUM),
   set_values_to = exprs(PARAMCD = "BMI"),
   get_unit_expr = VSSTRESU,
-  filter = VSSTAT != "NOT DONE" | is.na(VSSTAT)
+  filter = VSSTAT != "NOT DONE" | is.na(VSSTAT),
+  constant_by_vars = exprs(USUBJID)
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   arrange(advs, USUBJID, VISITNUM, VSTPTNUM, ADT, PARAMCD),
-  display_vars = exprs(USUBJID, VSTESTCD, PARAMCD, VISIT, VSTPT, AVAL, AVALC),
+  display_vars = exprs(USUBJID, VSTESTCD, PARAMCD, VISIT, VSTPT, AVAL),
   filter = PARAMCD %in% c("BSA", "BMI")
 )
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  
-#  adeg <- tibble::tribble(
-#    ~USUBJID, ~EGSTRESU, ~PARAMCD, ~AVAL, ~VISIT,
-#    "P01", "msec", "QT", 350, "CYCLE 1 DAY 1",
-#    "P01", "msec", "QT", 370, "CYCLE 2 DAY 1",
-#    "P01", "msec", "RR", 842, "CYCLE 1 DAY 1",
-#    "P01", "msec", "RR", 710, "CYCLE 2 DAY 1"
-#  )
-#  
-#  adeg <- derive_param_qtc(
-#    adeg,
-#    by_vars = exprs(USUBJID, VISIT),
-#    method = "Fridericia",
-#    set_values_to = exprs(PARAMCD = "QTCFR"),
-#    get_unit_expr = EGSTRESU
-#  )
+# adeg <- tibble::tribble(
+#   ~USUBJID, ~EGSTRESU, ~PARAMCD, ~AVAL,          ~VISIT,
+#   "P01",       "msec",     "QT",   350, "CYCLE 1 DAY 1",
+#   "P01",       "msec",     "QT",   370, "CYCLE 2 DAY 1",
+#   "P01",       "msec",     "RR",   842, "CYCLE 1 DAY 1",
+#   "P01",       "msec",     "RR",   710, "CYCLE 2 DAY 1"
+# )
+# 
+# adeg <- derive_param_qtc(
+#   adeg,
+#   by_vars = exprs(USUBJID, VISIT),
+#   method = "Fridericia",
+#   set_values_to = exprs(PARAMCD = "QTCFR"),
+#   get_unit_expr = EGSTRESU
+# )
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  adlb <- tibble::tribble(
-#    ~USUBJID, ~PARAMCD, ~AVAL, ~PARAM, ~VISIT,
-#    "P01", "WBC", 33, "Leukocyte Count (10^9/L)", "CYCLE 1 DAY 1",
-#    "P01", "WBC", 38, "Leukocyte Count (10^9/L)", "CYCLE 2 DAY 1",
-#    "P01", "LYMLE", 0.90, "Lymphocytes (fraction of 1)", "CYCLE 1 DAY 1",
-#    "P01", "LYMLE", 0.70, "Lymphocytes (fraction of 1)", "CYCLE 2 DAY 1"
-#  )
-#  
-#  derive_param_wbc_abs(
-#    dataset = adlb,
-#    by_vars = exprs(USUBJID, VISIT),
-#    set_values_to = exprs(
-#      PARAMCD = "LYMPH",
-#      PARAM = "Lymphocytes Abs (10^9/L)",
-#      DTYPE = "CALCULATION"
-#    ),
-#    get_unit_expr = extract_unit(PARAM),
-#    wbc_code = "WBC",
-#    diff_code = "LYMLE",
-#    diff_type = "fraction"
-#  )
+# adlb <- tibble::tribble(
+#   ~USUBJID, ~PARAMCD, ~AVAL,                        ~PARAM,          ~VISIT,
+#   "P01",       "WBC",    33,    "Leukocyte Count (10^9/L)", "CYCLE 1 DAY 1",
+#   "P01",       "WBC",    38,    "Leukocyte Count (10^9/L)", "CYCLE 2 DAY 1",
+#   "P01",     "LYMLE",  0.90, "Lymphocytes (fraction of 1)", "CYCLE 1 DAY 1",
+#   "P01",     "LYMLE",  0.70, "Lymphocytes (fraction of 1)", "CYCLE 2 DAY 1"
+# )
+# 
+# derive_param_wbc_abs(
+#   dataset = adlb,
+#   by_vars = exprs(USUBJID, VISIT),
+#   set_values_to = exprs(
+#     PARAMCD = "LYMPH",
+#     PARAM = "Lymphocytes Abs (10^9/L)",
+#     DTYPE = "CALCULATION"
+#   ),
+#   get_unit_expr = extract_unit(PARAM),
+#   wbc_code = "WBC",
+#   diff_code = "LYMLE",
+#   diff_type = "fraction"
+# )
 
 ## ----eval=TRUE----------------------------------------------------------------
-
 # Derive PARAM and PARAMN
 advs <- derive_vars_merged(
   advs,
@@ -235,7 +232,7 @@ advs <- derive_vars_merged(
   by_vars = exprs(PARAMCD)
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(VSTESTCD, PARAMCD, PARAM, PARAMN, PARCAT1, PARCAT1N),
@@ -272,7 +269,7 @@ advs <- derive_var_ontrtfl(
   ref_end_date = TRTEDT
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, PARAMCD, ADT, TRTSDT, TRTEDT, ONTRTFL),
@@ -307,10 +304,10 @@ advs <- derive_var_ontrtfl(
 advs_pre <- select(advs, -ONTRTFL)
 
 advs <- tibble::tribble(
-  ~USUBJID, ~ASTDT, ~AP01SDT, ~AP01EDT, ~AENDT,
+  ~USUBJID,         ~ASTDT,          ~AP01SDT,          ~AP01EDT,            ~AENDT,
   "P01", ymd("2020-03-15"), ymd("2020-01-01"), ymd("2020-03-01"), ymd("2020-12-01"),
   "P02", ymd("2019-04-30"), ymd("2020-01-01"), ymd("2020-03-01"), ymd("2020-03-15"),
-  "P03", ymd("2019-04-30"), ymd("2020-01-01"), ymd("2020-03-01"), NA,
+  "P03", ymd("2019-04-30"), ymd("2020-01-01"), ymd("2020-03-01"),                NA,
 )
 
 ## ----eval=TRUE----------------------------------------------------------------
@@ -321,10 +318,10 @@ advs <- derive_var_ontrtfl(
   end_date = AENDT,
   ref_start_date = AP01SDT,
   ref_end_date = AP01EDT,
-  span_period = "Y"
+  span_period = TRUE
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, ASTDT, AENDT, AP01SDT, AP01EDT, ONTR01FL)
@@ -348,7 +345,7 @@ advs <- derive_vars_merged(
 ## ----eval=TRUE----------------------------------------------------------------
 advs <- derive_var_anrind(advs)
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, PARAMCD, AVAL, ANRLO, ANRHI, A1LO, A1HI, ANRIND),
@@ -356,9 +353,9 @@ dataset_vignette(
 )
 
 ## ----eval=TRUE----------------------------------------------------------------
-advs <- derive_var_basetype(
+advs <- derive_basetype_records(
   dataset = advs,
-  basetypes = rlang::exprs(
+  basetypes = exprs(
     "LAST: AFTER LYING DOWN FOR 5 MINUTES" = ATPTN == 815,
     "LAST: AFTER STANDING FOR 1 MINUTE" = ATPTN == 816,
     "LAST: AFTER STANDING FOR 3 MINUTES" = ATPTN == 817,
@@ -381,7 +378,7 @@ advs <- restrict_derivation(
   filter = (!is.na(AVAL) & ADT <= TRTSDT & !is.na(BASETYPE))
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, BASETYPE, PARAMCD, ADT, TRTSDT, ATPTN, TRTSDT, ABLFL),
@@ -396,13 +393,6 @@ advs <- derive_var_base(
   new_var = BASE
 )
 
-advs <- derive_var_base(
-  advs,
-  by_vars = exprs(STUDYID, USUBJID, PARAMCD, BASETYPE),
-  source_var = AVALC,
-  new_var = BASEC
-)
-
 advs <- derive_var_base(
   advs,
   by_vars = exprs(STUDYID, USUBJID, PARAMCD, BASETYPE),
@@ -410,10 +400,10 @@ advs <- derive_var_base(
   new_var = BNRIND
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
-  display_vars = exprs(USUBJID, BASETYPE, PARAMCD, ABLFL, BASE, BASEC, ANRIND, BNRIND),
+  display_vars = exprs(USUBJID, BASETYPE, PARAMCD, ABLFL, BASE, ANRIND, BNRIND),
   filter = PARAMCD == "DIABP" & VISIT %in% c("WEEK 2", "BASELINE")
 )
 
@@ -422,7 +412,7 @@ advs <- derive_var_chg(advs)
 
 advs <- derive_var_pchg(advs)
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, VISIT, BASE, AVAL, CHG, PCHG),
@@ -436,6 +426,13 @@ advs <- derive_var_shift(advs,
   to_var = ANRIND
 )
 
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+dataset_vignette(
+  advs,
+  display_vars = exprs(USUBJID, SHIFT1, BNRIND, ANRIND, VISIT),
+  filter = PARAMCD == "DIABP" & VISIT %in% c("WEEK 2", "WEEK 8")
+)
+
 ## ----eval=TRUE----------------------------------------------------------------
 advs <- derive_var_analysis_ratio(advs,
   numer_var = AVAL,
@@ -448,7 +445,7 @@ advs <- derive_var_analysis_ratio(advs,
   new_var = R01ANRLO
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, VISIT, BASE, AVAL, ANRLO, R2BASE, R01ANRLO),
@@ -456,7 +453,6 @@ dataset_vignette(
 )
 
 ## ----eval=TRUE----------------------------------------------------------------
-
 advs <- restrict_derivation(
   advs,
   derivation = derive_var_extreme_flag,
@@ -469,7 +465,7 @@ advs <- restrict_derivation(
   filter = !is.na(AVISITN)
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, PARAMCD, AVISIT, ATPTN, ADT, AVAL, ANL01FL),
@@ -496,7 +492,7 @@ advs <- slice_derivation(
 ) %>%
   arrange(STUDYID, USUBJID, BASETYPE, PARAMCD, AVISIT)
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, PARAMCD, AVISIT, AVAL, ADT, ATPTN, WORSTFL),
@@ -517,7 +513,7 @@ advs <- derive_var_obs_number(
   check_type = "error"
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, PARAMCD, ADT, AVISITN, ATPTN, VISIT, ADT, ASEQ),
@@ -525,33 +521,76 @@ dataset_vignette(
 )
 
 ## ----eval=TRUE----------------------------------------------------------------
-avalcat_lookup <- tibble::tribble(
-  ~PARAMCD, ~AVALCA1N, ~AVALCAT1,
-  "HEIGHT", 1, ">140 cm",
-  "HEIGHT", 2, "<= 140 cm"
+avalcat_lookup <- exprs(
+  ~PARAMCD,  ~condition,   ~AVALCAT1, ~AVALCA1N,
+  "HEIGHT",  AVAL > 140,   ">140 cm",         1,
+  "HEIGHT", AVAL <= 140, "<= 140 cm",         2
 )
-
-format_avalcat1n <- function(param, aval) {
-  case_when(
-    param == "HEIGHT" & aval > 140 ~ 1,
-    param == "HEIGHT" & aval <= 140 ~ 2
-  )
-}
-
 advs <- advs %>%
-  mutate(AVALCA1N = format_avalcat1n(param = PARAMCD, aval = AVAL)) %>%
-  derive_vars_merged(
-    avalcat_lookup,
-    by = exprs(PARAMCD, AVALCA1N)
+  derive_vars_cat(
+    definition = avalcat_lookup,
+    by_vars = exprs(PARAMCD)
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, PARAMCD, AVAL, AVALCA1N, AVALCAT1),
   filter = PARAMCD == "HEIGHT"
 )
 
+## ----eval=TRUE----------------------------------------------------------------
+advs <- advs %>%
+  slice_derivation(
+    derivation = derive_vars_crit_flag,
+    args = params(
+      values_yn = TRUE,
+      create_numeric_flag = TRUE
+    ),
+    derivation_slice(
+      filter = PARAMCD == "SYSBP",
+      args = params(
+        condition = AVAL > 160,
+        description = "Systolic Pressure > 160"
+      )
+    ),
+    derivation_slice(
+      filter = PARAMCD == "DIABP",
+      args = params(
+        condition = AVAL > 95,
+        description = "Diastolic Pressure > 95"
+      )
+    )
+  )
+
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+dataset_vignette(
+  arrange(advs, USUBJID, AVISITN, ATPTN, PARAMCD),
+  display_vars = exprs(USUBJID, PARAMCD, AVAL, CHG, CRIT1, CRIT1FL, CRIT1FN),
+  filter = PARAMCD %in% c("DIABP", "SYSBP")
+)
+
+## ----eval=TRUE----------------------------------------------------------------
+advs <- advs %>%
+  restrict_derivation(
+    derivation = derive_vars_crit_flag,
+    args = params(
+      condition = AVAL > 160 & CHG > 10,
+      description = "Systolic Pressure > 160 and Change from Baseline in Systolic Pressure > 10",
+      crit_nr = 2,
+      values_yn = TRUE,
+      create_numeric_flag = TRUE
+    ),
+    filter = PARAMCD == "SYSBP"
+  )
+
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
+dataset_vignette(
+  arrange(advs, USUBJID, AVISITN, ATPTN),
+  display_vars = exprs(USUBJID, PARAMCD, AVAL, CHG, CRIT2, CRIT2FL, CRIT2FN),
+  filter = PARAMCD == "SYSBP"
+)
+
 ## ----eval=TRUE----------------------------------------------------------------
 advs <- advs %>%
   derive_vars_merged(
@@ -559,7 +598,7 @@ advs <- advs %>%
     by_vars = exprs(STUDYID, USUBJID)
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   advs,
   display_vars = exprs(USUBJID, RFSTDTC, RFENDTC, DTHDTC, DTHFL, AGE, AGEU),
@@ -569,10 +608,11 @@ dataset_vignette(
 ## ----eval=TRUE----------------------------------------------------------------
 advs_ex1 <- advs %>%
   derive_extreme_records(
+    dataset_add = advs,
     by_vars = exprs(STUDYID, USUBJID, PARAMCD),
     order = exprs(ADT, AVISITN, ATPTN, AVAL),
     mode = "last",
-    filter = (4 < AVISITN & AVISITN <= 12 & ANL01FL == "Y"),
+    filter_add = (4 < AVISITN & AVISITN <= 12 & ANL01FL == "Y"),
     set_values_to = exprs(
       AVISIT = "End of Treatment",
       AVISITN = 99,
@@ -580,7 +620,7 @@ advs_ex1 <- advs %>%
     )
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   arrange(advs_ex1, USUBJID, PARAMCD, desc(AVISITN), ATPTN),
   display_vars = exprs(USUBJID, PARAMCD, ADT, AVISITN, AVISIT, ATPTN, AVAL, DTYPE, ANL01FL),
@@ -590,10 +630,11 @@ dataset_vignette(
 ## ----eval=TRUE----------------------------------------------------------------
 advs_ex1 <- advs %>%
   derive_extreme_records(
+    dataset_add = advs,
     by_vars = exprs(STUDYID, USUBJID, PARAMCD),
     order = exprs(AVAL, ADT, AVISITN, ATPTN),
     mode = "first",
-    filter = (4 < AVISITN & AVISITN <= 12 & ANL01FL == "Y" & !is.na(AVAL)),
+    filter_add = (4 < AVISITN & AVISITN <= 12 & ANL01FL == "Y" & !is.na(AVAL)),
     set_values_to = exprs(
       AVISIT = "Minimum on Treatment",
       AVISITN = 98,
@@ -601,7 +642,7 @@ advs_ex1 <- advs %>%
     )
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   arrange(advs_ex1, USUBJID, PARAMCD, desc(AVISITN), ATPTN),
   display_vars = exprs(USUBJID, PARAMCD, ADT, AVISITN, AVISIT, ATPTN, AVAL, DTYPE, ANL01FL),
@@ -611,13 +652,15 @@ dataset_vignette(
 ## ----eval=TRUE----------------------------------------------------------------
 advs_ex2 <- derive_summary_records(
   advs,
+  dataset_add = advs,
   by_vars = exprs(STUDYID, USUBJID, PARAMCD, VISITNUM, ADT),
-  analysis_var = AVAL,
-  summary_fun = mean,
-  set_values_to = exprs(DTYPE = "AVERAGE")
+  set_values_to = exprs(
+    AVAL = mean(AVAL, na.rm = TRUE),
+    DTYPE = "AVERAGE"
+  )
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   arrange(advs_ex2, USUBJID, PARAMCD, VISITNUM, ADT, DTYPE),
   display_vars = exprs(USUBJID, PARAMCD, VISITNUM, ADT, AVAL, DTYPE),
@@ -629,14 +672,14 @@ advs_ex3 <- derive_param_computed(
   advs,
   by_vars = exprs(USUBJID, VISIT, ATPT),
   parameters = c("SYSBP", "DIABP"),
-  analysis_value = (AVAL.SYSBP - AVAL.DIABP) / 3 + AVAL.DIABP,
   set_values_to = exprs(
+    AVAL = (AVAL.SYSBP - AVAL.DIABP) / 3 + AVAL.DIABP,
     PARAMCD = "MAP2",
     PARAM = "Mean Arterial Pressure 2 (mmHg)"
   )
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   arrange(advs_ex3, USUBJID, VISIT, ATPT, PARAMCD),
   display_vars = exprs(USUBJID, PARAMCD, VISIT, ATPT, AVAL),
